pub enum EntryLabelMode {
Compact,
Forms,
}Expand description
Which already validated entry facts supply a display label first.
Variants
Compact
Names, then complete visible forms, then the existing identity.
Forms
Complete visible forms, then the compact fallback.