pub enum ExcerptSelection {
Tldr {
outline: OutlineTrail,
document: TldrDocument,
},
DocumentRoot {
outline: OutlineTrail,
heading: Option<Heading>,
blocks: Vec<Block>,
},
DocumentSection {
outline: OutlineTrail,
section: Section,
},
DocumentEntry {
outline: OutlineTrail,
entry: Block,
},
}Expand description
One selected document node together with its location in the complete outline.
Variants
Tldr
Optional quick-reference content preceding the primary document.
Fields

outline: OutlineTrailComplete logical location in the document outline.

document: TldrDocumentComplete quick-reference content.
DocumentRoot
Complete document content that appears before the first heading.
Fields

outline: OutlineTrailComplete logical location in the document outline.
DocumentSection
Complete selected document node, including all descendant sections.
Fields

outline: OutlineTrailComplete logical location in the document outline.
DocumentEntry
One addressable owner with its complete, original content.
Fields

outline: OutlineTrailComplete logical location in the document outline.
Implementations
Sourceimpl ExcerptSelection
impl ExcerptSelection
Sourcepub const fn outline(&self) -> &OutlineTrail
pub const fn outline(&self) -> &OutlineTrail
Return the complete logical location of this selection.