pub enum ExplanationOutcome {
Evidence,
NoEvidence,
}Expand description
A normal result outcome, independent of pagination and source coverage.
Variants
Evidence
At least one supporting owner was found before pagination.
NoEvidence
No owner was found by the bounded rules; not proof of absence of behavior.