pub enum TraversalLimit {
MaxDepth,
MaxDocuments,
MaxContentBytes,
}Expand description
Traversal bound that excluded an outbound logical link.
Variants
MaxDepth
The maximum number of followed link edges was reached.
MaxDocuments
The maximum number of distinct loaded documents was reached.
MaxContentBytes
Retaining another normalized document would exceed the aggregate semantic-content budget.