pub enum UnloadedFragment {
Absent {},
Unchecked {},
}Expand description
Fragment facts permitted before a target document is loaded.
Variants
Absent
Original target did not specify a fragment.
Unchecked
Original fragment is retained in the target, but has not been checked.