pub struct DoctorEnvironment {
pub os: String,
pub arch: String,
pub data_root: Option<String>,
pub config_path: Option<String>,
pub documents_root: Option<String>,
pub sources_root: Option<String>,
pub manual_roots: Vec<String>,
pub tldr_roots: Vec<String>,
}Expand description
Effective local paths and host identity inspected by mant --doctor.
Fields
os: StringRust host operating-system family.
arch: StringRust host processor architecture.
data_root: Option<String>Platform-native ManT data root, when it could be derived.
config_path: Option<String>Effective sources.toml path, when the data root is available.
documents_root: Option<String>Personal Markdown root, when the data root is available.
sources_root: Option<String>Managed source root, when the data root is available.
manual_roots: Vec<String>Native manual roots in effective precedence order.
tldr_roots: Vec<String>tldr cache roots in effective read order.