pub struct ExplanationTruncation {
pub candidates: bool,
pub relations: bool,
pub content: bool,
}Expand description
Independent reasons that a bounded explanation may omit material.
Fields
candidates: boolCollection hit its matching-owner budget.
relations: boolRelation traversal hit its edge or depth budget.
content: boolSome selected body, details or previews were omitted by the copy budget.