pub struct OutlineTrail {
pub ancestors: Vec<OutlineReference>,
pub node: OutlineNodeReference,
}Expand description
Complete logical location of one addressable document node.
Fields
ancestors: Vec<OutlineReference>Ordered ancestors from the document root to the direct parent.
node: OutlineNodeReferenceSelected or matching node at the end of the trail.
Implementations