pub struct QueryExcerpt {
pub schema: ExcerptSchema,
pub label: String,
pub producer: Option<Producer>,
pub source: Option<DocumentSource>,
pub meta: Option<DocumentMeta>,
pub diagnostics: Vec<Diagnostic>,
pub selections: Vec<ExcerptSelection>,
}Expand description
One or more independently selected nodes from a complete query.
Fields
schema: ExcerptSchemaExact response schema discriminator.
label: StringHuman-readable selected-document label.
producer: Option<Producer>Process and parser provenance, when a document was loaded.
source: Option<DocumentSource>Authoritative document source, when one was loaded.
meta: Option<DocumentMeta>Document metadata, when one was loaded.
diagnostics: Vec<Diagnostic>Recoverable parser and validation findings.
selections: Vec<ExcerptSelection>Selected nodes in request order.