pub struct ResolvedDocumentScope {
pub query: DocumentScope,
pub documents: Vec<ScopedDocument>,
pub edges: Vec<DocumentEdge>,
pub frontier: Vec<DocumentFrontier>,
pub unresolved: Vec<UnresolvedDocument>,
}Expand description
Logical graph produced before applying a projection.
Fields
query: DocumentScopeOriginal normalized scope request.
documents: Vec<ScopedDocument>Distinct documents in deterministic breadth-first order.
edges: Vec<DocumentEdge>Successfully resolved typed edges in source order.
frontier: Vec<DocumentFrontier>Typed outbound links excluded by depth, document, or content limits.
unresolved: Vec<UnresolvedDocument>Seeds and edges that could not resolve to a readable document.