pub enum ExcerptSelection {
Tldr {
path: NodePath,
id: NodeId,
title: String,
document: TldrDocument,
},
DocumentRoot {
path: NodePath,
id: NodeId,
title: String,
blocks: Vec<Block>,
},
DocumentSection {
path: NodePath,
id: NodeId,
title: String,
breadcrumbs: Vec<OutlineReference>,
section: Section,
},
DocumentEntry {
path: NodePath,
id: NodeId,
title: String,
breadcrumbs: Vec<OutlineReference>,
entry: DefinitionItem,
},
}Expand description
One selected document node together with its location in the complete outline.
Variants
Tldr
Optional quick-reference content preceding the primary document.
Fields

document: TldrDocumentComplete quick-reference content.
DocumentRoot
Complete document content that appears before the first heading.
Fields
DocumentSection
Complete selected document node, including all descendant sections.
Fields
Ordered ancestors from the document root to the parent section.
DocumentEntry
One addressable semantic definition and its complete description.